{% load jmbo_template_tags foundry_tags i18n %}

<div class="title">
    {% if object.categories.all.count %}<span class="category">{{ object.categories.all|join_titles }}:</span>{% endif %}
    <a href="{{ object.get_absolute_url }}">{{ object.title }}</a>
</div>

{% include "includes/list_meta.html" %}
