
{% with object.get_items as items %}
    <div class="items">
        <ul id="gallery">
        {% for item in items %}
            <div class="item {% if forloop.first %}first{% endif %} {% if forloop.last %}last{% endif %}">
                <li>
                    <img 
                        src="{{ item.get_gallery_detail_image_LAYER_url }}" 
                        frame="{{ item.get_gallery_detail_image_LAYER_url }}" 
                        title="{{ item.title }}" 
                        longdesc="{{ item.description }}"
                        />
                </li>
            </div>
        {% endfor %}
        </ul>
        <div class="clear"></div>
    </div>

{% endwith %}
