{% extends "base.html" %}
{% load i18n %}

{% block content %}
<div class="content member-detail">

    <div class="title">{{ object.username }}</div>
    {% if object.about_me %}
        <p>{{ object.about_me }}</p>
    {% endif %}
    <p>
        {% blocktrans %}This user does not have a public profile.{% endblocktrans %}
    </p>

</div>    
{% endblock content %}
