{% comment %}
todo: This template must be backported to jmbo itself.
{% endcomment %}

{% load likes_inclusion_tags i18n %}

<div class="object-header">    
    <div class="title">
	    {{ object.title }}
    </div>

	<div class="meta">

        <div class="byline">
            {% blocktrans %}By{% endblocktrans %} <a href="{{ object.owner.get_absolute_url }}">{{ object.owner }}</a> {% blocktrans %}on{% endblocktrans %} {{ object.created|date:"j F Y" }}
        </div>

        {% if object.comments_enabled %}
        <div class="comments">
            {% with object.comment_count as total %}
                ({{ total }} {% if total == 1 %}{% trans "comment" %}{% else %}{% trans "comments" %}{% endif %})
            {% endwith %}
        </div>
        {% endif %}

        {% if object.likes_enabled %}
        <div class="likes">
            {% likes object %}
        </div>
        {% endif %}

    </div>

</div>
