{% comment %}
Add social widgets from addthis.com
{% endcomment %}

{% load likes_inclusion_tags i18n %}

<div class="object-header">    
    <div class="title">
	    {{ object.title }}
    </div>

	<div class="meta">

        <div class="byline">
            {% blocktrans %}By{% endblocktrans %} <a href="{{ object.owner.get_absolute_url }}">{{ object.owner }}</a> {% blocktrans %}on{% endblocktrans %} {{ object.created|date:"j F Y" }}
        </div>

        {% if object.comments_enabled %}
        <div class="comments">
            {% with object.comment_count as total %}
                ({{ total }} {% if total == 1 %}{% trans "comment" %}{% else %}{% trans "comments" %}{% endif %})
            {% endwith %}
        </div>
        {% endif %}

        {% if object.likes_enabled %}
        <div class="likes">
            {% likes object %}
        </div>
        {% endif %}

        <div class="addthis">
            <div class="addthis_toolbox addthis_default_style ">
            <a class="addthis_button_facebook_like" fb:like:layout="button_count"></a>
            <a class="addthis_button_tweet"></a>
            <a class="addthis_button_google_plusone" g:plusone:size="medium"></a>
            <a class="addthis_counter addthis_pill_style"></a>
            </div>        
            <script type="text/javascript" src="http://s7.addthis.com/js/300/addthis_widget.js#pubid=xa-4f044e2e0586e005"></script>
        </div>

    </div>

</div>
