ul.errorlist {
    margin: 0 0 12px -3.1em;
}    

ul.errorlist li {
    margin: 0;
    color: red;
}

div.errorlist {
    margin-bottom: 12px;
}    

div.errorlist div.error {
    color: red;
}

form.foundry-form { 
    margin: 0; 
    padding: 0;
    background-color: #f9f9f9; 
    border: 1px solid #e5e5e5; 
    padding: 5px; 
    margin: 0.5em 0;
}

form.foundry-form-inline { 
    margin: 0; 
    padding: 0;
    border: 1px solid #e5e5e5; 
    padding: 5px; 
    margin: 0.5em 0;
}

ul.form-ul {
    margin-top: 0;
}

ul.form-ul li {
    margin-bottom: 6px;
    margin-left: -40px;
    list-style: none;
}

ul.form-ul ul.errorlist, ul.form-ul div.errorlist {
    margin: 0;
}    

ul.form-ul label {
    display: block;
    margin-bottom: 2px;
}    

ul.form-ul .helptext {
    display: block;
    margin-bottom: 2px;
    color: #7e7e7e;
}    

div.field {
    margin-bottom: 6px;
}

div.field ul.errorlist {
    margin: 0 0 0 -3.1em;
}    

div.field div.errorlist {
    margin: 0;
}    

div.field label {
    display: block;
    margin-bottom: 2px;
}    

div.field .helptext {
    display: block;
    margin-bottom: 2px;
    color: #7e7e7e;
}    

li.required > label, div.required > label {
    background-image: url('/static/basic/images/red-asterisk.png');
    background-position: left center;
    background-repeat: no-repeat;
    padding-left: 16px;
}    
