{% load jmbo_template_tags jmbo_inclusion_tags pagination_tags %}

{% if object_list.exists %}
    <div class="foundry-container foundry-listing-vertical">
        <div class="title">{{ listing.title }}</div>
        <div class="items">
        {% autopaginate object_list items_per_page %}
        {% for object in object_list %}
            <div class="item {% if forloop.first %}first{% endif %} {% if forloop.last %}last{% endif %} item-{{ object.class_name|lower }}">
                {% render_object object.as_leaf_class "list_item" %}
            </div>
        {% endfor %}
        </div>
        {% paginate %}
    </div>
{% endif %}
