{% extends "base.html" %}
{% load jmbo_inclusion_tags %} 

{% block content %}
    <div class="h2">{{ title }}</div>

    {% view_modifier view_modifier %}

    <div class="items">
    {% for object in object_list %}
        <div class="item {% if forloop.first %}first{% endif %} {% if forloop.last %}last{% endif %}">
            {% render_object object 'list_item' %}
        </div>
    {% endfor %}
    </div>

    {% pager page_obj %}
{% endblock %}
