{% extends "base.html" %}
{% comment %}
    Slight html change to style it like the other forms
{% endcomment %}

{% load i18n %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{% trans 'Home' %}</a> &rsaquo; {% trans 'Password reset confirmation' %}</div>{% endblock %}

{% block title %}{% trans 'Password reset' %}{% endblock %}

{% block content %}

{% if validlink %}

<div class="h2">{% trans 'Enter new password' %}</div>

<p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>

<form action="" method="post">{% csrf_token %}
<div class="field">
<div class="required">
{{ form.new_password1.errors }}
<label for="id_new_password1">{% trans 'New password:' %}</label>{{ form.new_password1 }}
</div>
</div>
<div class="field">
<div class="required">
{{ form.new_password2.errors }}
<label for="id_new_password2">{% trans 'Confirm password:' %}</label>{{ form.new_password2 }}</p>
</div>
</div>
<p><input type="submit" value="{% trans 'Change my password' %}" /></p>
</form>

{% else %}

<h1>{% trans 'Password reset unsuccessful' %}</h1>

<p>{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}</p>

{% endif %}

{% endblock %}
