{% extends "base.html" %}
{% load i18n %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../../">{% trans 'Home' %}</a> &rsaquo; {% trans 'Password reset' %}</div>{% endblock %}

{% block title %}{% trans 'Password reset complete' %}{% endblock %}

{% block content %}

<div class="h2">{% trans 'Password reset complete' %}</div>

<p>{% trans "Your password has been set. You may go ahead and log in now." %}</p>

<p><a href="{{ login_url }}">{% trans 'Log in' %}</a></p>

{% endblock %}
