{% extends "base.html" %}
{% load jmbo_inclusion_tags %} 

{% block content %}
    {% view_modifier view_modifier %}

    {% object_header object %}

    {{ object.content|safe }}

    {% object_comments object %}
{% endblock %}

