{% load foundry_tags i18n compress jmbo_analytics_tags %}

<?xml version="1.0" encoding="utf-8"?> 
<!DOCTYPE html PUBLIC "-//WAPFORUM//DTD XHTML Mobile 1.0//EN" "http://www.wapforum.org/DTD/xhtml-mobile10.dtd"> 
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <meta property="og:site_name" content="{{ CURRENT_SITE.name }}" />
    {% block extrameta %}
    <meta property="og:title" content="{{ CURRENT_SITE.name }}" />
    <meta property="og:image" content="{{ STATIC_URL }}images/logo.jpg" />
    <meta property="og:description" content="Jmbo is a mobile-focused content delivery platform for the delivery of dynamic experiences to audiences in emerging markets." />
    {% endblock %}
    <title>{{ CURRENT_SITE.name }}</title>
    {% compress css %}
    <link href="{{ STATIC_URL }}css/main.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/tile.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/comment.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/forms.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/gallery.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/promo.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/custom.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="{{ STATIC_URL }}images/favicon.ico" />
    {% endcompress %}    
    <script type="text/javascript" src="{{ STATIC_URL }}admin/thirdparty/jquery-1.6.2.min.js"></script>
    {% compress js %}
    <script src="{{ STATIC_URL }}js/foundry.js" type="text/javascript"></script>
    <script src="{{ STATIC_URL }}js/gallery.js" type="text/javascript"></script>
    <script src="{{ STATIC_URL }}js/promo.js" type="text/javascript"></script>
    <script src="{{ STATIC_URL }}js/custom.js" type="text/javascript"></script>
    {% endcompress %}
    {% block extra-head %}
    {% endblock %}
</head>

<body>

    {% block header %}
        {% rows 'header' %}
    {% endblock %}

    <div id="message">        
    {% block message %}
        {% if messages %}
            <ul class="messagelist">
                {% for message in messages %}<li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>{% endfor %}
            </ul>
        {% endif %}
    {% endblock %}
    </div>

    <div id="content">        
        {% block content %}
        <div id="page-content">        
        {% block page_content %}
            {% rows 'content' %}
        {% endblock %}
        </div>
        {% endblock %}
        {% comment %}
        {% if request.user.is_authenticated %}
            {% suggested_friends request.user %}
        {% endif %}
        {% endcomment %}
    </div>

    {% block footer %}
        {% rows 'footer' %}
    {% endblock %}

    {% if ANALYTICS_TAGS %}
        {{ ANALYTICS_TAGS|safe }}
    {% endif %}

    <img src="{% google_analytics %}" width="0" height="0" />

</body>
</html>
