{% load i18n compress %}

<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <link href="{{ STATIC_URL }}css/main.css" rel="stylesheet" type="text/css" />
    <link href="{{ STATIC_URL }}css/custom.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="{{ STATIC_URL }}images/favicon.ico" />
</head>

<body>

<div class="content">
    <h1>{% trans "A system error has occurred" %}</h1>
    {% blocktrans %}The system has encountered an error. The relevant people have already been notified.{% endblocktrans %}
</div>

</body>
</html>
