{% extends "base.html" %}

{% load i18n %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{% trans 'Home' %}</a> &rsaquo; {% trans 'Password reset' %}</div>{% endblock %}

{% block title %}{% trans "Password reset" %}{% endblock %}

{% block content %}
<div class="content">

<div class="title">{% trans "Password reset" %}</div>

{% if form.email %}
<p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>
{% endif %}
{% if form.mobile_number %}
<p>{% trans "Forgotten your password? Enter your mobile number below, and we'll send instructions for setting a new one." %}</p>
{% endif %}


<form action="" method="post">{% csrf_token %}
{{ form.as_div }}
<div class="buttons">
    <input type="submit" value="{% trans 'Reset my password' %}" />
</div>
</form>

</div>
{% endblock %}
