{% extends "base.html" %}

{% block content %}

    <div class="h2">Pages</div>
    
    {% for page in object_list %}
        <a href="{% url page-detail page.slug %}">{{ page.title }}</a><br />
    {% endfor %}

{% endblock %}
