{% extends "base.html" %}
{% load i18n %}

{% block content %}
<div class="content"> 

    <div class="title">{% trans "Sign up" %}</div>

    <form action="{% url join %}" method="POST" enctype="multipart/form-data" class="foundry-form">   
        {% csrf_token %}
        {{ form.as_div }}
        <div class="buttons">
            <input type="submit" value="{% trans "Sign up" %}" />
        </div>
    </form>

</div>
{% endblock content %}
