{% extends "base.html" %}
{% load i18n %}

{% block content %}
<div class="content">

    <div class="title">{% trans "Sign in" %}</div>

    <form action="{% url login %}" method="POST" class="foundry-form">
        {% csrf_token %}
        <input type="hidden" name="next" value="{{ request.REQUEST.next }}" />
        {{ form.as_div }}
        <div class="buttons">
        	<input type="submit" value="{% trans "Sign in" %}" />
        </div>
        <span><a href="/auth/password_reset">{% blocktrans %}Forgot your password?{% endblocktrans %}</a></span>
        <span>{% trans "Not registered?" %} <a href="{% url join %}">{% trans "Sign up here" %}</a></span>
    </form>

</div>
{% endblock %}
