{% extends "base.html" %}

{% block content %}

<form method="POST" action="." class="foundry-form">
    {% csrf_token %}
    {{ form.as_div }}
    <input type="submit" value="Submit" />
</form>

{% endblock %}
