{% extends "base.html" %}
{% load i18n %}

{% block breadcrumbs %}<div class="breadcrumbs"><a href="../">{% trans 'Home' %}</a> &rsaquo; {% trans 'Password reset' %}</div>{% endblock %}

{% block title %}{% trans 'Password reset successful' %}{% endblock %}

{% block content %}

<div class="h2">{% trans 'Password reset successful' %}</div>

<p>{% trans "We've sent you instructions for setting your password. You should be receiving it shortly." %}</p>

{% endblock %}
