{% load foundry_tags i18n %}

<div id="header">
    <a href="/"><img src="{{ STATIC_URL }}images/logo.png" alt="" /></a>
    <div class="buttons">
      {% if request.user.is_authenticated %}
        <span><a href="{% url member-detail request.user.username %}">{% trans "My profile" %}</a></span>
        <span><a href="{% url logout %}">{% trans "Sign out" %}</a></span>
      {% endif %}
      {% if request.user.is_anonymous %}
          <span><a href="{% url login %}">{% trans "Sign in" %}</a></span>
          <span><a href="{% url join %}">{% trans "Join" %}</a></span>
      {% endif %}
  	</div>
</div>

{% navbar 'main' %}
