{% extends "base.html" %}
{% load foundry_tags %}

{% block page_content %}
    {% with object.rows_by_block_name.content as rows %}
        {% include "foundry/inclusion_tags/rows.html" %}
    {% endwith %}
{% endblock %}
